##

###

##

##

###

###

    	objectives

    		ranked

    			[ ] giveaways:

    				verify your USA citizenship and you can receive some.

    	possibilites

    		[ ] assets are minted later?
    			[ ] how?

    			but why?  just create a new currency trend at some point ;)

    	possible names
    		best names ranked

    			eco

    			praise

    			thanks

    			tickets
    			slips
    			gems
    			coins
    			shares

    		possible names

    			equity, fungi